##  Authentication Flow
SAP LeanIX employs the [OAuth 2.0![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=http%3A%2F%2Foauth.net%2F2%2F "http://oauth.net/2/") protocol for user authentication across all available APIs. In the image below, you can see how the authentication process works for an example API request.
![SAP LeanIX OAuth 2.0 flow](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2742535e7a4410149508d9ddca6c1895_LowRes.png)
SAP LeanIX OAuth 2.0 Flow
